@@ -16,15 +16,16 @@
 */
 
 #include <gtest/gtest.h>
-#include "ignition/gazebo/test_config.hh"
-#include "ignition/gazebo/components/Component.hh"
-#include "ignition/gazebo/components/Factory.hh"
-#include "ignition/gazebo/components/Pose.hh"
+#include "gz/sim/test_config.hh"
+#include "gz/sim/components/Component.hh"
+#include "gz/sim/components/Factory.hh"
+#include "gz/sim/components/Name.hh"
+#include "gz/sim/components/Pose.hh"
 
 #include "../test/helpers/EnvTestFixture.hh"
 
-using namespace ignition;
-using namespace gazebo;
+using namespace gz;
+using namespace gz::sim;
 
 /////////////////////////////////////////////////
 class ComponentFactoryTest : public InternalFixture<::testing::Test>
@@ -54,8 +55,7 @@ TEST_F(ComponentFactoryTest, Register)
   auto registeredCount = factory->TypeIds().size();
 
   factory->Register<MyCustom>("ign_gazebo_components.MyCustom",
-      new components::ComponentDescriptor<MyCustom>(),
-      new components::StorageDescriptor<MyCustom>());
+      new components::ComponentDescriptor<MyCustom>());
 
   // Check now it has type id
   EXPECT_NE(0u, MyCustom::typeId);
@@ -68,10 +68,9 @@ TEST_F(ComponentFactoryTest, Register)
   EXPECT_EQ(registeredCount + 1, ids.size());
   EXPECT_NE(ids.end(), std::find(ids.begin(), ids.end(), MyCustom::typeId));
 
-  // Fail to register same component twice
+  // Registering the component twice doesn't change the number of type ids.
   factory->Register<MyCustom>("ign_gazebo_components.MyCustom",
-      new components::ComponentDescriptor<MyCustom>(),
-      new components::StorageDescriptor<MyCustom>());
+      new components::ComponentDescriptor<MyCustom>());
 
   EXPECT_EQ(registeredCount + 1, factory->TypeIds().size());
 
@@ -79,19 +78,15 @@ TEST_F(ComponentFactoryTest, Register)
   using Duplicate = components::Component<components::NoData,
       class DuplicateTag>;
   factory->Register<Duplicate>("ign_gazebo_components.MyCustom",
-      new components::ComponentDescriptor<Duplicate>(),
-      new components::StorageDescriptor<Duplicate>());
+      new components::ComponentDescriptor<Duplicate>());
 
   EXPECT_EQ(registeredCount + 1, factory->TypeIds().size());
 
   // Unregister
   factory->Unregister<MyCustom>();
 
-  // Check it has no type id yet
   ids = factory->TypeIds();
-  EXPECT_EQ(registeredCount, ids.size());
-  EXPECT_EQ(0u, MyCustom::typeId);
-  EXPECT_EQ("", factory->Name(MyCustom::typeId));
+  EXPECT_EQ(registeredCount + 1, ids.size());
 }
 
 /////////////////////////////////////////////////
@@ -101,12 +96,12 @@ TEST_F(ComponentFactoryTest, New)
 
   {
     auto comp = factory->New(123456789);
-    ASSERT_TRUE(comp == nullptr);
+    ASSERT_EQ(nullptr, comp);
   }
 
   {
     auto comp = factory->New<components::Pose>();
-    ASSERT_TRUE(comp != nullptr);
+    ASSERT_NE(nullptr, comp);
 
     EXPECT_NE(0u, comp->typeId);
     EXPECT_EQ(comp->typeId, components::Pose::typeId);
@@ -114,19 +109,33 @@ TEST_F(ComponentFactoryTest, New)
 
   {
     auto comp = factory->New(components::Pose::typeId);
-    ASSERT_TRUE(comp != nullptr);
+    ASSERT_NE(nullptr, comp);
 
     EXPECT_NE(0u, comp->TypeId());
 
-    EXPECT_TRUE(nullptr != static_cast<components::Pose *>(comp.get()));
+    EXPECT_NE(nullptr, static_cast<components::Pose *>(comp.get()));
   }
 
   {
-    auto storage = factory->NewStorage(components::Pose::typeId);
-    ASSERT_TRUE(storage != nullptr);
+    // Test constructing a component with pre-defined data
 
-    EXPECT_NE(nullptr, static_cast<ComponentStorage<components::Pose> *>(
-        storage.get()));
+    // Test a valid pre-defined component
+    ignition::math::Pose3d pose(1, 2, 3, 4, 5, 6);
+    components::Pose poseComp(pose);
+    auto comp = factory->New(components::Pose::typeId, &poseComp);
+    ASSERT_NE(nullptr, comp);
+    EXPECT_NE(0u, comp->TypeId());
+    auto derivedComp = static_cast<components::Pose *>(comp.get());
+    ASSERT_NE(nullptr, derivedComp);
+    EXPECT_EQ(pose, derivedComp->Data());
+
+    // Test an invalid pre-defined component
+    comp = factory->New(components::Pose::typeId, nullptr);
+    ASSERT_EQ(nullptr, comp);
+
+    // Test mistmatching component types
+    comp = factory->New(components::Name::typeId, &poseComp);
+    ASSERT_EQ(nullptr, comp);
   }
 }
 
