@@ -16,23 +16,24 @@
  */
 
 #include <gtest/gtest.h>
-#include <ignition/msgs/int32.pb.h>
+#include <gz/msgs/int32.pb.h>
+#include <gz/utilities/ExtraTestMacros.hh>
 
 #include <memory>
 
 #include <sdf/Element.hh>
-#include <ignition/common/Console.hh>
-#include <ignition/math/Inertial.hh>
+#include <gz/common/Console.hh>
+#include <gz/math/Inertial.hh>
 
-#include "ignition/gazebo/components/Component.hh"
-#include "ignition/gazebo/components/Serialization.hh"
-#include "ignition/gazebo/components/Name.hh"
-#include "ignition/gazebo/EntityComponentManager.hh"
+#include "gz/sim/components/Component.hh"
+#include "gz/sim/components/Serialization.hh"
+#include "gz/sim/components/Name.hh"
+#include "gz/sim/EntityComponentManager.hh"
 
 #include "../test/helpers/EnvTestFixture.hh"
 
-using namespace ignition;
-using namespace gazebo;
+using namespace gz;
+using namespace gz::sim;
 
 //////////////////////////////////////////////////
 class ComponentTest : public InternalFixture<::testing::Test>
@@ -61,7 +62,8 @@ TEST_F(ComponentTest, ComponentCanBeCopiedAfterDefaultCtor)
 }
 
 //////////////////////////////////////////////////
-TEST_F(ComponentTest, DataByMove)
+// See https://github.com/ignitionrobotics/ign-gazebo/issues/1175
+TEST_F(ComponentTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(DataByMove))
 {
   auto factory = components::Factory::Instance();
 
@@ -330,7 +332,7 @@ TEST_F(ComponentTest, OStream)
     EXPECT_EQ("Mass: 0", ostr.str());
   }
 
-  // Component with a ignition::msgs type that gets serialized by the default
+  // Component with a msgs type that gets serialized by the default
   // serializer
   {
     using Custom = components::Component<msgs::Int32, class CustomTag,
@@ -482,7 +484,7 @@ TEST_F(ComponentTest, IStream)
     EXPECT_DOUBLE_EQ(200, comp.Data()->MassMatrix().Mass());
   }
 
-  // Component with a ignition::msgs type that gets deserialized by the message
+  // Component with a msgs type that gets deserialized by the message
   // deserializer
   {
     using Custom = components::Component<msgs::Int32, class CustomTag,
