@@ -1424,6 +1424,41 @@ sdf::Sensor gazebo::convert(const msgs::Sensor &_in)
 
     out.SetCameraSensor(sensor);
   }
+  else if (out.Type() == sdf::SensorType::GPS ||
+           out.Type() == sdf::SensorType::NAVSAT)
+  {
+    sdf::NavSat sensor;
+    if (_in.has_gps())
+    {
+      if (_in.gps().position().has_horizontal_noise())
+      {
+        sensor.SetHorizontalPositionNoise(gazebo::convert<sdf::Noise>(
+              _in.gps().position().horizontal_noise()));
+      }
+      if (_in.gps().position().has_vertical_noise())
+      {
+        sensor.SetVerticalPositionNoise(gazebo::convert<sdf::Noise>(
+              _in.gps().position().vertical_noise()));
+      }
+      if (_in.gps().velocity().has_horizontal_noise())
+      {
+        sensor.SetHorizontalVelocityNoise(gazebo::convert<sdf::Noise>(
+              _in.gps().velocity().horizontal_noise()));
+      }
+      if (_in.gps().velocity().has_vertical_noise())
+      {
+        sensor.SetVerticalVelocityNoise(gazebo::convert<sdf::Noise>(
+              _in.gps().velocity().vertical_noise()));
+      }
+    }
+    else
+    {
+      ignerr << "Attempting to convert a navsat sensor message, but the "
+             << "message does not have a navsat nested message.\n";
+    }
+
+    out.SetNavSatSensor(sensor);
+  }
   else if (out.Type() == sdf::SensorType::ALTIMETER)
   {
     sdf::Altimeter sensor;
@@ -1678,9 +1713,8 @@ msgs::ParticleEmitter ignition::gazebo::convert(const sdf::ParticleEmitter &_in)
   {
     std::string path = asFullPath(_in.ColorRangeImage(), _in.FilePath());
 
-    common::SystemPaths systemPaths;
-    systemPaths.SetFilePathEnv(kResourcePathEnv);
-    std::string absolutePath = systemPaths.FindFile(path);
+    const std::string absolutePath =
+        common::SystemPaths::LocateLocalFile(path, gazebo::resourcePaths());
 
     if (!absolutePath.empty())
       out.mutable_color_range_image()->set_data(absolutePath);
