@@ -30,29 +30,46 @@
 using namespace gz;
 using namespace sim;
 
+#ifdef _WIN32
+  constexpr const char *kPluginDir = "bin";
+#else
+  constexpr const char *kPluginDir = "lib";
+#endif
 /////////////////////////////////////////////////
 TEST(SystemLoader, Constructor)
 {
-  gz::sim::SystemLoader sm;
-
   // Add test plugin to path (referenced in config)
   auto testBuildPath = common::joinPaths(
-      std::string(PROJECT_BINARY_PATH), "lib");
-  sm.AddSystemPluginPath(testBuildPath);
+      std::string(PROJECT_BINARY_PATH), kPluginDir);
 
   sdf::Root root;
   root.LoadSdfString(std::string("<?xml version='1.0'?><sdf version='1.6'>"
-      "<world name='default'>"
-      "<plugin filename='libignition-gazebo") +
-      IGNITION_GAZEBO_MAJOR_VERSION_STR + "-physics-system.so' "
-      "name='gz::sim::systems::Physics'></plugin>"
+      "<world name='default'>") +
+      "<plugin filename='libignition-gazebo" +
+      IGNITION_GAZEBO_MAJOR_VERSION_STR + "-user-commands-system.so' "
+      "name='gz::sim::systems::UserCommands'></plugin>"
+      "<plugin filename='ignition-gazebo" +
+      IGNITION_GAZEBO_MAJOR_VERSION_STR + "-user-commands-system' "
+      "name='gz::sim::systems::UserCommands'></plugin>"
+      "<plugin filename='ignition-gazebo-user-commands-system' "
+      "name='gz::sim::systems::UserCommands'></plugin>"
+      "<plugin filename='libgz-sim" +
+      IGNITION_GAZEBO_MAJOR_VERSION_STR + "-user-commands-system.so' "
+      "name='gz::sim::systems::UserCommands'></plugin>"
+      "<plugin filename='gz-sim" +
+      IGNITION_GAZEBO_MAJOR_VERSION_STR + "-user-commands-system' "
+      "name='gz::sim::systems::UserCommands'></plugin>"
+      "<plugin filename='gz-sim-user-commands-system' "
+      "name='gz::sim::systems::UserCommands'></plugin>"
       "</world></sdf>");
-
+  ASSERT_NE(root.WorldByIndex(0), nullptr);
   auto worldElem = root.WorldByIndex(0)->Element();
   if (worldElem->HasElement("plugin")) {
     sdf::ElementPtr pluginElem = worldElem->GetElement("plugin");
     while (pluginElem)
     {
+      gz::sim::SystemLoader sm;
+      sm.AddSystemPluginPath(testBuildPath);
       sdf::Plugin plugin;
       plugin.Load(pluginElem);
       auto system = sm.LoadPlugin(plugin);
@@ -61,6 +78,48 @@ TEST(SystemLoader, Constructor)
     }
   }
 }
+/////////////////////////////////////////////////
+TEST(SystemLoader, FromPluginPathEnv)
+{
+  sdf::Root root;
+  root.LoadSdfString(R"(<?xml version='1.0'?>
+    <sdf version='1.6'>
+      <world name='default'>
+        <plugin filename='MockSystem' name='gz::sim::MockSystem'/>
+      </world>
+    </sdf>)");
+
+  ASSERT_NE(root.WorldCount(), 0u);
+  auto world = root.WorldByIndex(0);
+  ASSERT_TRUE(world != nullptr);
+  ASSERT_FALSE(world->Plugins().empty());
+  auto plugin = world->Plugins()[0];
+
+  {
+    gz::sim::SystemLoader sm;
+    auto system = sm.LoadPlugin(plugin);
+    EXPECT_FALSE(system.has_value());
+  }
+
+  const auto libPath = common::joinPaths(PROJECT_BINARY_PATH, kPluginDir);
+
+  {
+    common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH", libPath.c_str());
+
+    gz::sim::SystemLoader sm;
+    auto system = sm.LoadPlugin(plugin);
+    EXPECT_TRUE(system.has_value());
+    EXPECT_TRUE(common::unsetenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH"));
+  }
+  {
+    common::setenv("GZ_SIM_SYSTEM_PLUGIN_PATH", libPath.c_str());
+
+    gz::sim::SystemLoader sm;
+    auto system = sm.LoadPlugin(plugin);
+    EXPECT_TRUE(system.has_value());
+    EXPECT_TRUE(common::unsetenv("GZ_SIM_SYSTEM_PLUGIN_PATH"));
+  }
+}
 
 TEST(SystemLoader, EmptyNames)
 {
