@@ -16,32 +16,32 @@
 */
 
 #include <gtest/gtest.h>
-#include <ignition/common/Console.hh>
+#include <gz/common/Console.hh>
 #include <sdf/Actor.hh>
 #include <sdf/Light.hh>
 #include <sdf/Types.hh>
 
-#include <ignition/fuel_tools/ClientConfig.hh>
+#include <gz/fuel_tools/ClientConfig.hh>
 
-#include "ignition/gazebo/components/Actor.hh"
-#include "ignition/gazebo/components/Collision.hh"
-#include "ignition/gazebo/components/Joint.hh"
-#include "ignition/gazebo/components/Light.hh"
-#include "ignition/gazebo/components/Link.hh"
-#include "ignition/gazebo/components/Model.hh"
-#include "ignition/gazebo/components/Name.hh"
-#include "ignition/gazebo/components/ParentEntity.hh"
-#include "ignition/gazebo/components/ParticleEmitter.hh"
-#include "ignition/gazebo/components/Sensor.hh"
-#include "ignition/gazebo/components/Visual.hh"
-#include "ignition/gazebo/components/World.hh"
-#include "ignition/gazebo/EntityComponentManager.hh"
-#include "ignition/gazebo/Util.hh"
+#include "gz/sim/components/Actor.hh"
+#include "gz/sim/components/Collision.hh"
+#include "gz/sim/components/Joint.hh"
+#include "gz/sim/components/Light.hh"
+#include "gz/sim/components/Link.hh"
+#include "gz/sim/components/Model.hh"
+#include "gz/sim/components/Name.hh"
+#include "gz/sim/components/ParentEntity.hh"
+#include "gz/sim/components/ParticleEmitter.hh"
+#include "gz/sim/components/Sensor.hh"
+#include "gz/sim/components/Visual.hh"
+#include "gz/sim/components/World.hh"
+#include "gz/sim/EntityComponentManager.hh"
+#include "gz/sim/Util.hh"
 
 #include "helpers/EnvTestFixture.hh"
 
-using namespace ignition;
-using namespace gazebo;
+using namespace gz;
+using namespace gz::sim;
 
 /// \brief Tests for Util.hh
 class UtilTest : public InternalFixture<::testing::Test>
@@ -70,8 +70,8 @@ TEST_F(UtilTest, ScopedName)
 
   // World
   auto worldEntity = ecm.CreateEntity();
-  EXPECT_EQ(kNullEntity, gazebo::worldEntity(ecm));
-  EXPECT_EQ(kNullEntity, gazebo::worldEntity(worldEntity, ecm));
+  EXPECT_EQ(kNullEntity, gz::sim::worldEntity(ecm));
+  EXPECT_EQ(kNullEntity, gz::sim::worldEntity(worldEntity, ecm));
   ecm.CreateComponent(worldEntity, components::World());
   ecm.CreateComponent(worldEntity, components::Name("world_name"));
 
@@ -214,22 +214,22 @@ TEST_F(UtilTest, ScopedName)
     "world_name::actorD_name");
 
   // World entity
-  EXPECT_EQ(worldEntity, gazebo::worldEntity(ecm));
-  EXPECT_EQ(worldEntity, gazebo::worldEntity(worldEntity, ecm));
-  EXPECT_EQ(worldEntity, gazebo::worldEntity(lightAEntity, ecm));
-  EXPECT_EQ(worldEntity, gazebo::worldEntity(modelBEntity, ecm));
-  EXPECT_EQ(worldEntity, gazebo::worldEntity(linkBEntity, ecm));
-  EXPECT_EQ(worldEntity, gazebo::worldEntity(lightBEntity, ecm));
-  EXPECT_EQ(worldEntity, gazebo::worldEntity(sensorBEntity, ecm));
-  EXPECT_EQ(worldEntity, gazebo::worldEntity(modelCEntity, ecm));
-  EXPECT_EQ(worldEntity, gazebo::worldEntity(linkCEntity, ecm));
-  EXPECT_EQ(worldEntity, gazebo::worldEntity(collisionCEntity, ecm));
-  EXPECT_EQ(worldEntity, gazebo::worldEntity(visualCEntity, ecm));
-  EXPECT_EQ(worldEntity, gazebo::worldEntity(jointCEntity, ecm));
-  EXPECT_EQ(worldEntity, gazebo::worldEntity(modelCCEntity, ecm));
-  EXPECT_EQ(worldEntity, gazebo::worldEntity(linkCCEntity, ecm));
-  EXPECT_EQ(worldEntity, gazebo::worldEntity(actorDEntity, ecm));
-  EXPECT_EQ(kNullEntity, gazebo::worldEntity(kNullEntity, ecm));
+  EXPECT_EQ(worldEntity, gz::sim::worldEntity(ecm));
+  EXPECT_EQ(worldEntity, gz::sim::worldEntity(worldEntity, ecm));
+  EXPECT_EQ(worldEntity, gz::sim::worldEntity(lightAEntity, ecm));
+  EXPECT_EQ(worldEntity, gz::sim::worldEntity(modelBEntity, ecm));
+  EXPECT_EQ(worldEntity, gz::sim::worldEntity(linkBEntity, ecm));
+  EXPECT_EQ(worldEntity, gz::sim::worldEntity(lightBEntity, ecm));
+  EXPECT_EQ(worldEntity, gz::sim::worldEntity(sensorBEntity, ecm));
+  EXPECT_EQ(worldEntity, gz::sim::worldEntity(modelCEntity, ecm));
+  EXPECT_EQ(worldEntity, gz::sim::worldEntity(linkCEntity, ecm));
+  EXPECT_EQ(worldEntity, gz::sim::worldEntity(collisionCEntity, ecm));
+  EXPECT_EQ(worldEntity, gz::sim::worldEntity(visualCEntity, ecm));
+  EXPECT_EQ(worldEntity, gz::sim::worldEntity(jointCEntity, ecm));
+  EXPECT_EQ(worldEntity, gz::sim::worldEntity(modelCCEntity, ecm));
+  EXPECT_EQ(worldEntity, gz::sim::worldEntity(linkCCEntity, ecm));
+  EXPECT_EQ(worldEntity, gz::sim::worldEntity(actorDEntity, ecm));
+  EXPECT_EQ(kNullEntity, gz::sim::worldEntity(kNullEntity, ecm));
 }
 
 /////////////////////////////////////////////////
@@ -740,8 +740,8 @@ TEST_F(UtilTest, EntityFromMsg)
 
   // World
   auto worldEntity = ecm.CreateEntity();
-  EXPECT_EQ(kNullEntity, gazebo::worldEntity(ecm));
-  EXPECT_EQ(kNullEntity, gazebo::worldEntity(worldEntity, ecm));
+  EXPECT_EQ(kNullEntity, gz::sim::worldEntity(ecm));
+  EXPECT_EQ(kNullEntity, gz::sim::worldEntity(worldEntity, ecm));
   ecm.CreateComponent(worldEntity, components::World());
   ecm.CreateComponent(worldEntity, components::Name("world"));
 
@@ -824,7 +824,7 @@ TEST_F(UtilTest, EntityFromMsg)
   ecm.CreateComponent(actorDEntity, components::ParentEntity(worldEntity));
 
   // Check entities
-  auto createMsg = [&ecm](Entity _id, const std::string &_name = "",
+  auto createMsg = [&](Entity _id, const std::string &_name = "",
       msgs::Entity::Type _type = msgs::Entity::NONE) -> msgs::Entity
   {
     msgs::Entity msg;
