@@ -15,18 +15,20 @@
  *
 */
 
-#include <ignition/math/Vector3.hh>
+#include <gz/math/SphericalCoordinates.hh>
+#include <gz/math/Vector3.hh>
 
-#include "ignition/gazebo/components/Actor.hh"
-#include "ignition/gazebo/components/Atmosphere.hh"
-#include "ignition/gazebo/components/Gravity.hh"
-#include "ignition/gazebo/components/Light.hh"
-#include "ignition/gazebo/components/MagneticField.hh"
-#include "ignition/gazebo/components/Model.hh"
-#include "ignition/gazebo/components/Name.hh"
-#include "ignition/gazebo/components/ParentEntity.hh"
-#include "ignition/gazebo/components/World.hh"
-#include "ignition/gazebo/World.hh"
+#include "gz/sim/components/Actor.hh"
+#include "gz/sim/components/Atmosphere.hh"
+#include "gz/sim/components/Gravity.hh"
+#include "gz/sim/components/Light.hh"
+#include "gz/sim/components/MagneticField.hh"
+#include "gz/sim/components/Model.hh"
+#include "gz/sim/components/Name.hh"
+#include "gz/sim/components/ParentEntity.hh"
+#include "gz/sim/components/SphericalCoordinates.hh"
+#include "gz/sim/components/World.hh"
+#include "gz/sim/World.hh"
 
 class ignition::gazebo::WorldPrivate
 {
@@ -34,11 +36,11 @@ class ignition::gazebo::WorldPrivate
   public: Entity id{kNullEntity};
 };
 
-using namespace ignition;
-using namespace gazebo;
+using namespace gz;
+using namespace gz::sim;
 
 //////////////////////////////////////////////////
-World::World(gazebo::Entity _entity)
+World::World(gz::sim::Entity _entity)
   : dataPtr(std::make_unique<WorldPrivate>())
 {
   this->dataPtr->id = _entity;
@@ -91,6 +93,34 @@ std::optional<sdf::Atmosphere> World::Atmosphere(
   return _ecm.ComponentData<components::Atmosphere>(this->dataPtr->id);
 }
 
+//////////////////////////////////////////////////
+std::optional<math::SphericalCoordinates> World::SphericalCoordinates(
+    const EntityComponentManager &_ecm) const
+{
+  return _ecm.ComponentData<components::SphericalCoordinates>(
+      this->dataPtr->id);
+}
+
+//////////////////////////////////////////////////
+void World::SetSphericalCoordinates(EntityComponentManager &_ecm,
+    const math::SphericalCoordinates &_sphericalCoordinates)
+{
+  auto sphericalCoordinatesComp =
+      _ecm.Component<components::SphericalCoordinates>(this->dataPtr->id);
+  if (!sphericalCoordinatesComp)
+  {
+    _ecm.CreateComponent(this->dataPtr->id,
+        components::SphericalCoordinates(_sphericalCoordinates));
+    return;
+  }
+
+  sphericalCoordinatesComp->SetData(_sphericalCoordinates,
+      [](const math::SphericalCoordinates &,
+         const math::SphericalCoordinates &){return false;});
+  _ecm.SetChanged(this->dataPtr->id,
+      components::SphericalCoordinates::typeId, ComponentState::OneTimeChange);
+}
+
 //////////////////////////////////////////////////
 std::optional<math::Vector3d> World::Gravity(
     const EntityComponentManager &_ecm) const
@@ -110,7 +140,7 @@ Entity World::LightByName(const EntityComponentManager &_ecm,
     const std::string &_name) const
 {
   // Can't use components::Light in EntityByComponents, see
-  // https://github.com/ignitionrobotics/ign-gazebo/issues/376
+  // https://github.com/gazebosim/gz-sim/issues/376
   auto entities = _ecm.EntitiesByComponents(
       components::ParentEntity(this->dataPtr->id),
       components::Name(_name));
@@ -128,7 +158,7 @@ Entity World::ActorByName(const EntityComponentManager &_ecm,
     const std::string &_name) const
 {
   // Can't use components::Actor in EntityByComponents, see
-  // https://github.com/ignitionrobotics/ign-gazebo/issues/376
+  // https://github.com/gazebosim/gz-sim/issues/376
   auto entities = _ecm.EntitiesByComponents(
       components::ParentEntity(this->dataPtr->id),
       components::Name(_name));
@@ -155,11 +185,11 @@ Entity World::ModelByName(const EntityComponentManager &_ecm,
 std::vector<Entity> World::Lights(const EntityComponentManager &_ecm) const
 {
   // Can't use components::Light in EntityByComponents, see
-  // https://github.com/ignitionrobotics/ign-gazebo/issues/376
+  // https://github.com/gazebosim/gz-sim/issues/376
   auto entities = _ecm.EntitiesByComponents(
       components::ParentEntity(this->dataPtr->id));
 
-  std::vector<gazebo::Entity> result;
+  std::vector<sim::Entity> result;
   for (const auto &entity : entities)
   {
     if (_ecm.Component<components::Light>(entity))
@@ -172,11 +202,11 @@ std::vector<Entity> World::Lights(const EntityComponentManager &_ecm) const
 std::vector<Entity> World::Actors(const EntityComponentManager &_ecm) const
 {
   // Can't use components::Actor in EntityByComponents, see
-  // https://github.com/ignitionrobotics/ign-gazebo/issues/376
+  // https://github.com/gazebosim/gz-sim/issues/376
   auto entities = _ecm.EntitiesByComponents(
       components::ParentEntity(this->dataPtr->id));
 
-  std::vector<gazebo::Entity> result;
+  std::vector<sim::Entity> result;
   for (const auto &entity : entities)
   {
     if (_ecm.Component<components::Actor>(entity))
@@ -210,4 +240,3 @@ uint64_t World::ModelCount(const EntityComponentManager &_ecm) const
 {
   return this->Models(_ecm).size();
 }
-
