@@ -30,9 +30,11 @@ GZ_SIM_COMPLETION_LIST="
   --record-path
   --record-resources
   --record-topic
+  --record-period
   --log-overwrite
   --log-compress
   --playback
+  --headless-rendering
   -r
   -s
   -v --verbose
@@ -54,8 +56,6 @@ function _gz_gazebo
 {
   if [[ ${COMP_WORDS[COMP_CWORD]} == -* ]]; then
     # Specify options (-*) word list for this subcommand
-    # TODO(anyone): In Fortress+, add --headless-rendering.
-    # Update ../gz_TEST.cc accordingly.
     COMPREPLY=($(compgen -W "$GZ_SIM_COMPLETION_LIST" \
       -- "${COMP_WORDS[COMP_CWORD]}" ))
     return
