@@ -15,8 +15,8 @@
  *
 */
 
-#include <ignition/msgs/boolean.pb.h>
-#include <ignition/msgs/vector3d.pb.h>
+#include <gz/msgs/boolean.pb.h>
+#include <gz/msgs/vector3d.pb.h>
 
 #include <algorithm>
 #include <iostream>
@@ -25,26 +25,26 @@
 #include <string>
 #include <vector>
 
-#include <ignition/common/Console.hh>
-#include <ignition/gui/Application.hh>
-#include <ignition/gui/GuiEvents.hh>
-#include <ignition/gui/MainWindow.hh>
-#include <ignition/plugin/Register.hh>
-#include <ignition/rendering/Geometry.hh>
-#include <ignition/rendering/Material.hh>
-#include <ignition/rendering/RenderEngine.hh>
-#include <ignition/rendering/RenderTypes.hh>
-#include <ignition/rendering/RenderingIface.hh>
-#include <ignition/rendering/Scene.hh>
-#include <ignition/rendering/Visual.hh>
-#include <ignition/rendering/WireBox.hh>
-#include <ignition/transport/Node.hh>
+#include <gz/common/Console.hh>
+#include <gz/gui/Application.hh>
+#include <gz/gui/GuiEvents.hh>
+#include <gz/gui/MainWindow.hh>
+#include <gz/plugin/Register.hh>
+#include <gz/rendering/Geometry.hh>
+#include <gz/rendering/Material.hh>
+#include <gz/rendering/RenderEngine.hh>
+#include <gz/rendering/RenderTypes.hh>
+#include <gz/rendering/RenderingIface.hh>
+#include <gz/rendering/Scene.hh>
+#include <gz/rendering/Visual.hh>
+#include <gz/rendering/WireBox.hh>
+#include <gz/transport/Node.hh>
 
-#include "ignition/gazebo/EntityComponentManager.hh"
-#include "ignition/gazebo/components/Name.hh"
-#include "ignition/gazebo/components/World.hh"
-#include "ignition/gazebo/gui/GuiEvents.hh"
-#include "ignition/gazebo/rendering/RenderUtil.hh"
+#include "gz/sim/EntityComponentManager.hh"
+#include "gz/sim/components/Name.hh"
+#include "gz/sim/components/World.hh"
+#include "gz/sim/gui/GuiEvents.hh"
+#include "gz/sim/rendering/RenderUtil.hh"
 
 #include "AlignTool.hh"
 
@@ -98,7 +98,7 @@ namespace ignition::gazebo
 }
 
 using namespace ignition;
-using namespace gazebo;
+using namespace ignition::gazebo;
 
 /////////////////////////////////////////////////
 AlignTool::AlignTool()
@@ -106,8 +106,8 @@ AlignTool::AlignTool()
 {
   // Deselect all entities upon loading plugin
   gui::events::DeselectAllEntities deselectEvent(true);
-  ignition::gui::App()->sendEvent(
-      ignition::gui::App()->findChild<ignition::gui::MainWindow *>(),
+  gz::gui::App()->sendEvent(
+      gz::gui::App()->findChild<gz::gui::MainWindow *>(),
       &deselectEvent);
 }
 
@@ -121,8 +121,8 @@ void AlignTool::LoadConfig(const tinyxml2::XMLElement *)
     this->title = "Align tool";
 
   // For align tool requests
-  ignition::gui::App()->findChild
-      <ignition::gui::MainWindow *>()->installEventFilter(this);
+  gz::gui::App()->findChild
+      <gz::gui::MainWindow *>()->installEventFilter(this);
 }
 
 /////////////////////////////////////////////////
@@ -352,19 +352,20 @@ void AlignTool::Align()
     this->dataPtr->scene = rendering::sceneFromFirstRenderEngine();
 
   // Get current list of selected entities
-  std::vector<ignition::rendering::VisualPtr> selectedList;
-  ignition::rendering::VisualPtr relativeVisual;
+  std::vector<rendering::VisualPtr> selectedList;
+  rendering::VisualPtr relativeVisual;
 
   for (const auto &entityId : this->dataPtr->selectedEntities)
   {
     for (auto i = 0u; i < this->dataPtr->scene->VisualCount(); ++i)
     {
-      ignition::rendering::VisualPtr vis =
+      rendering::VisualPtr vis =
         this->dataPtr->scene->VisualByIndex(i);
       if (!vis)
         continue;
 
-      if (std::get<int>(vis->UserData("gazebo-entity")) ==
+      if (vis->HasUserData("gazebo-entity") &&
+          std::get<int>(vis->UserData("gazebo-entity")) ==
           static_cast<int>(entityId))
       {
         // Check here to see if visual is top level or not, continue if not
@@ -388,8 +389,8 @@ void AlignTool::Align()
     (relativeVisual = selectedList.back());
 
   // Callback function for ignition node request
-  std::function<void(const ignition::msgs::Boolean &, const bool)> cb =
-      [](const ignition::msgs::Boolean &/* _rep*/, const bool _result)
+  std::function<void(const msgs::Boolean &, const bool)> cb =
+      [](const msgs::Boolean &/* _rep*/, const bool _result)
   {
     if (!_result)
       ignerr << "Error setting pose" << std::endl;
@@ -403,7 +404,7 @@ void AlignTool::Align()
   }
 
   int axisIndex = static_cast<int>(this->dataPtr->axis);
-  ignition::msgs::Pose req;
+  msgs::Pose req;
 
   ignition::math::AxisAlignedBox targetBox = relativeVisual->BoundingBox();
   ignition::math::Vector3d targetMin = targetBox.Min();
@@ -550,7 +551,7 @@ rendering::NodePtr AlignTool::TopLevelNode(rendering::ScenePtr &_scene,
 /////////////////////////////////////////////////
 bool AlignTool::eventFilter(QObject *_obj, QEvent *_event)
 {
-  if (_event->type() == ignition::gui::events::Render::kType)
+  if (_event->type() == gz::gui::events::Render::kType)
   {
     // This event is called in Scene3d's RenderThread, so it's safe to make
     // rendering calls here
@@ -565,7 +566,7 @@ bool AlignTool::eventFilter(QObject *_obj, QEvent *_event)
     }
   }
   else if (_event->type() ==
-           ignition::gazebo::gui::events::EntitiesSelected::kType)
+           gui::events::EntitiesSelected::kType)
   {
     auto selectedEvent =
         reinterpret_cast<ignition::gazebo::gui::events::EntitiesSelected *>(
@@ -588,7 +589,7 @@ bool AlignTool::eventFilter(QObject *_obj, QEvent *_event)
     }
   }
   else if (_event->type() ==
-           ignition::gazebo::gui::events::DeselectAllEntities::kType)
+           gui::events::DeselectAllEntities::kType)
   {
     this->dataPtr->selectedEntities.clear();
   }
@@ -596,5 +597,5 @@ bool AlignTool::eventFilter(QObject *_obj, QEvent *_event)
 }
 
 // Register this plugin
-IGNITION_ADD_PLUGIN(ignition::gazebo::AlignTool,
-                    ignition::gui::Plugin)
+IGNITION_ADD_PLUGIN(AlignTool,
+                    gz::gui::Plugin)
