@@ -159,12 +159,18 @@ TEST(CmdLine, IGN_UTILS_TEST_DISABLED_ON_WIN32(ResourcePath))
 
   // Correct path
   auto path = std::string("IGN_GAZEBO_RESOURCE_PATH=") +
-    PROJECT_SOURCE_PATH + "/test/worlds ";
+              gz::common::joinPaths(PROJECT_SOURCE_PATH, "test", "worlds ");
 
   output = customExecStr(path + cmd);
   EXPECT_EQ(output.find("Unable to find file plugins.sdf"), std::string::npos)
       << output;
 
+  path = std::string("GZ_SIM_RESOURCE_PATH=") +
+         gz::common::joinPaths(PROJECT_SOURCE_PATH, "test", "worlds ");
+  output = customExecStr(path + cmd);
+  EXPECT_EQ(output.find("Unable to find file plugins.sdf"), std::string::npos)
+      << output;
+
   // Several paths
   path = std::string("IGN_GAZEBO_RESOURCE_PATH=banana:") +
     PROJECT_SOURCE_PATH + "/test/worlds:orange ";
@@ -172,6 +178,25 @@ TEST(CmdLine, IGN_UTILS_TEST_DISABLED_ON_WIN32(ResourcePath))
   output = customExecStr(path + cmd);
   EXPECT_EQ(output.find("Unable to find file plugins.sdf"), std::string::npos)
       << output;
+
+  // Test nested models
+  // Use a direct path to the input file. Using a file name that has to be
+  // resolved interacts with how resource environment variables are processed
+  // and so will have different behavior than when a direct path is provided.
+  cmd = kIgnCommand + " -s -r -v 4 --iterations 1 " +
+        gz::common::joinPaths(PROJECT_SOURCE_PATH, "test", "worlds",
+                              "include_nested_models.sdf");
+  output = customExecStr(cmd);
+  EXPECT_NE(output.find("Unable to find"), std::string::npos) << output;
+
+  std::string pathValue =
+      gz::common::joinPaths(PROJECT_SOURCE_PATH, "test", "worlds", "models");
+
+  output = customExecStr("IGN_GAZEBO_RESOURCE_PATH=" + pathValue + " " + cmd);
+  EXPECT_EQ(output.find("Unable to find"), std::string::npos) << output;
+
+  output = customExecStr("GZ_SIM_RESOURCE_PATH=" + pathValue + " " + cmd);
+  EXPECT_EQ(output.find("Unable to find"), std::string::npos) << output;
 }
 
 //////////////////////////////////////////////////
