@@ -18,11 +18,11 @@
 
 #include <algorithm>
 
-#include "ignition/common/Console.hh"
-#include "ignition/common/Util.hh"
+#include "gz/common/Console.hh"
+#include "gz/common/Util.hh"
 
-using namespace ignition;
-using namespace gazebo;
+using namespace gz;
+using namespace gz::sim;
 
 /////////////////////////////////////////////////
 NetworkConfig NetworkConfig::FromValues(const std::string &_role,
@@ -50,14 +50,14 @@ NetworkConfig NetworkConfig::FromValues(const std::string &_role,
     else
     {
       config.role = NetworkRole::None;
-      ignwarn << "Invalid setting for IGN_GAZEBO_NETWORK_ROLE: " << role
+      ignwarn << "Invalid setting for network role: " << role
               << "(expected: PRIMARY, SECONDARY, READONLY)"
               << ", distributed sim disabled" << std::endl;
     }
   }
   else
   {
-      ignwarn << "IGN_GAZEBO_NETWORK_ROLE not set"
+      ignwarn << "Network role not set"
               << ", distributed sim disabled" << std::endl;
   }
 
@@ -68,8 +68,8 @@ NetworkConfig NetworkConfig::FromValues(const std::string &_role,
     if (config.numSecondariesExpected == 0)
     {
       config.role = NetworkRole::None;
-      ignwarn << "Detected IGN_GAZEBO_NETWORK_ROLE=PRIMARY, but "
-        << "IGN_GAZEBO_NETWORK_SECONDARIES not set, "
+      ignwarn << "Detected network role as PRIMARY, but "
+        << "network secondaries not set, "
         << "no distributed sim available" << std::endl;
     }
   }
