@@ -265,9 +265,9 @@ void NetworkManagerPrimary::PopulateAffinities(
   {
     auto secondaryIt = this->secondaries.begin();
 
-    for (const auto &[level, performers] : lToPNew)
+    for (const auto &it : lToPNew)
     {
-      for (const auto &performer : performers)
+      for (const auto &performer : it.second)
       {
         this->SetAffinity(performer, secondaryIt->second->prefix,
             _msg.add_affinity());
