@@ -21,7 +21,7 @@
 #include <mutex>
 #include <string>
 
-#include <ignition/msgs.hh>
+#include <gz/msgs.hh>
 #include <gz/transport/Node.hh>
 
 #include "gz/sim/Events.hh"
@@ -377,6 +377,8 @@ rendering::MarkerType MarkerManagerPrivate::MsgToType(
   {
     case msgs::Marker::BOX:
       return rendering::MarkerType::MT_BOX;
+    case msgs::Marker::CAPSULE:
+      return rendering::MarkerType::MT_CAPSULE;
     case msgs::Marker::CYLINDER:
       return rendering::MarkerType::MT_CYLINDER;
     case msgs::Marker::LINE_STRIP:
