@@ -17,29 +17,29 @@
 
 #include "JointController.hh"
 
-#include <ignition/msgs/double.pb.h>
+#include <gz/msgs/double.pb.h>
 
 #include <string>
 
-#include <ignition/common/Profiler.hh>
-#include <ignition/math/PID.hh>
-#include <ignition/plugin/Register.hh>
-#include <ignition/transport/Node.hh>
+#include <gz/common/Profiler.hh>
+#include <gz/math/PID.hh>
+#include <gz/plugin/Register.hh>
+#include <gz/transport/Node.hh>
 
-#include "ignition/gazebo/components/JointForceCmd.hh"
-#include "ignition/gazebo/components/JointVelocity.hh"
-#include "ignition/gazebo/components/JointVelocityCmd.hh"
-#include "ignition/gazebo/Model.hh"
+#include "gz/sim/components/JointForceCmd.hh"
+#include "gz/sim/components/JointVelocity.hh"
+#include "gz/sim/components/JointVelocityCmd.hh"
+#include "gz/sim/Model.hh"
 
-using namespace ignition;
-using namespace gazebo;
+using namespace gz;
+using namespace gz::sim;
 using namespace systems;
 
 class ignition::gazebo::systems::JointControllerPrivate
 {
   /// \brief Callback for velocity subscription
   /// \param[in] _msg Velocity message
-  public: void OnCmdVel(const ignition::msgs::Double &_msg);
+  public: void OnCmdVel(const msgs::Double &_msg);
 
   /// \brief Ignition communication node.
   public: transport::Node node;
@@ -47,9 +47,6 @@ class ignition::gazebo::systems::JointControllerPrivate
   /// \brief Joint Entity
   public: Entity jointEntity;
 
-  /// \brief Joint name
-  public: std::string jointName;
-
   /// \brief Commanded joint velocity
   public: double jointVelCmd;
 
@@ -64,7 +61,7 @@ class ignition::gazebo::systems::JointControllerPrivate
   public: bool useForceCommands{false};
 
   /// \brief Velocity PID controller.
-  public: ignition::math::PID velPid;
+  public: math::PID velPid;
 };
 
 //////////////////////////////////////////////////
@@ -89,15 +86,23 @@ void JointController::Configure(const Entity &_entity,
   }
 
   // Get params from SDF
-  this->dataPtr->jointName = _sdf->Get<std::string>("joint_name");
-
-  if (this->dataPtr->jointName == "")
+  auto jointName = _sdf->Get<std::string>("joint_name");
+  if (jointName.empty())
   {
     ignerr << "JointController found an empty jointName parameter. "
            << "Failed to initialize.";
     return;
   }
 
+  this->dataPtr->jointEntity = this->dataPtr->model.JointByName(_ecm,
+      jointName);
+  if (this->dataPtr->jointEntity == kNullEntity)
+  {
+    ignerr << "Joint with name[" << jointName << "] not found. "
+    << "The JointController may not control this joint.\n";
+    return;
+  }
+
   if (_sdf->HasElement("initial_velocity"))
   {
     this->dataPtr->jointVelCmd = _sdf->Get<double>("initial_velocity");
@@ -139,11 +144,11 @@ void JointController::Configure(const Entity &_entity,
 
   // Subscribe to commands
   std::string topic = transport::TopicUtils::AsValidTopic("/model/" +
-      this->dataPtr->model.Name(_ecm) + "/joint/" + this->dataPtr->jointName +
+      this->dataPtr->model.Name(_ecm) + "/joint/" + jointName +
       "/cmd_vel");
   if (topic.empty())
   {
-    ignerr << "Failed to create topic for joint [" << this->dataPtr->jointName
+    ignerr << "Failed to create topic for joint [" << jointName
            << "]" << std::endl;
     return;
   }
@@ -155,7 +160,7 @@ void JointController::Configure(const Entity &_entity,
     if (topic.empty())
     {
       ignerr << "Failed to create topic [" << _sdf->Get<std::string>("topic")
-             << "]" << " for joint [" << this->dataPtr->jointName
+             << "]" << " for joint [" << jointName
              << "]" << std::endl;
       return;
     }
@@ -168,11 +173,15 @@ void JointController::Configure(const Entity &_entity,
 }
 
 //////////////////////////////////////////////////
-void JointController::PreUpdate(const ignition::gazebo::UpdateInfo &_info,
-    ignition::gazebo::EntityComponentManager &_ecm)
+void JointController::PreUpdate(const UpdateInfo &_info,
+    EntityComponentManager &_ecm)
 {
   IGN_PROFILE("JointController::PreUpdate");
 
+  // If the joint hasn't been identified yet, the plugin is disabled
+  if (this->dataPtr->jointEntity == kNullEntity)
+    return;
+
   // \TODO(anyone) Support rewind
   if (_info.dt < std::chrono::steady_clock::duration::zero())
   {
@@ -181,16 +190,6 @@ void JointController::PreUpdate(const ignition::gazebo::UpdateInfo &_info,
         << "s]. System may not work properly." << std::endl;
   }
 
-  // If the joint hasn't been identified yet, look for it
-  if (this->dataPtr->jointEntity == kNullEntity)
-  {
-    this->dataPtr->jointEntity =
-        this->dataPtr->model.JointByName(_ecm, this->dataPtr->jointName);
-  }
-
-  if (this->dataPtr->jointEntity == kNullEntity)
-    return;
-
   // Nothing left to do if paused.
   if (_info.paused)
     return;
@@ -215,19 +214,22 @@ void JointController::PreUpdate(const ignition::gazebo::UpdateInfo &_info,
   // Force mode.
   if (this->dataPtr->useForceCommands)
   {
-    double error = jointVelComp->Data().at(0) - targetVel;
-    double force = this->dataPtr->velPid.Update(error, _info.dt);
+    if (!jointVelComp->Data().empty())
+    {
+      double error = jointVelComp->Data().at(0) - targetVel;
+      double force = this->dataPtr->velPid.Update(error, _info.dt);
 
-    auto forceComp =
-        _ecm.Component<components::JointForceCmd>(this->dataPtr->jointEntity);
-    if (forceComp == nullptr)
-    {
-      _ecm.CreateComponent(this->dataPtr->jointEntity,
-                           components::JointForceCmd({force}));
-    }
-    else
-    {
-      forceComp->Data()[0] = force;
+      auto forceComp =
+          _ecm.Component<components::JointForceCmd>(this->dataPtr->jointEntity);
+      if (forceComp == nullptr)
+      {
+        _ecm.CreateComponent(this->dataPtr->jointEntity,
+                             components::JointForceCmd({force}));
+      }
+      else
+      {
+        forceComp->Data()[0] = force;
+      }
     }
   }
   // Velocity mode.
@@ -243,7 +245,7 @@ void JointController::PreUpdate(const ignition::gazebo::UpdateInfo &_info,
           this->dataPtr->jointEntity,
           components::JointVelocityCmd({targetVel}));
     }
-    else
+    else if (!vel->Data().empty())
     {
       vel->Data()[0] = targetVel;
     }
@@ -258,9 +260,13 @@ void JointControllerPrivate::OnCmdVel(const msgs::Double &_msg)
 }
 
 IGNITION_ADD_PLUGIN(JointController,
-                    ignition::gazebo::System,
+                    System,
                     JointController::ISystemConfigure,
                     JointController::ISystemPreUpdate)
 
+IGNITION_ADD_PLUGIN_ALIAS(JointController,
+                          "gz::sim::systems::JointController")
+
+// TODO(CH3): Deprecated, remove on version 8
 IGNITION_ADD_PLUGIN_ALIAS(JointController,
                           "ignition::gazebo::systems::JointController")
