@@ -17,39 +17,38 @@
 
 #include "LogPlayback.hh"
 
-#include <ignition/msgs/pose_v.pb.h>
-#include <ignition/msgs/log_playback_stats.pb.h>
+#include <gz/msgs/log_playback_stats.pb.h>
 
 #include <set>
 #include <string>
 #include <unordered_map>
 
-#include <ignition/common/Filesystem.hh>
-#include <ignition/common/Profiler.hh>
-#include <ignition/fuel_tools/Zip.hh>
-#include <ignition/math/Pose3.hh>
-#include <ignition/msgs/Utility.hh>
-#include <ignition/plugin/RegisterMore.hh>
-#include <ignition/transport/log/QueryOptions.hh>
-#include <ignition/transport/log/Log.hh>
-#include <ignition/transport/log/Message.hh>
+#include <gz/common/Filesystem.hh>
+#include <gz/common/Profiler.hh>
+#include <gz/fuel_tools/Zip.hh>
+#include <gz/math/Pose3.hh>
+#include <gz/msgs/Utility.hh>
+#include <gz/plugin/RegisterMore.hh>
+#include <gz/transport/log/QueryOptions.hh>
+#include <gz/transport/log/Log.hh>
+#include <gz/transport/log/Message.hh>
 
 #include <sdf/Geometry.hh>
 #include <sdf/Mesh.hh>
 #include <sdf/Root.hh>
 
-#include "ignition/gazebo/Conversions.hh"
-#include "ignition/gazebo/Events.hh"
-#include "ignition/gazebo/SdfEntityCreator.hh"
-#include "ignition/gazebo/components/Geometry.hh"
-#include "ignition/gazebo/components/LogPlaybackStatistics.hh"
-#include "ignition/gazebo/components/Material.hh"
-#include "ignition/gazebo/components/ParticleEmitter.hh"
-#include "ignition/gazebo/components/Pose.hh"
-#include "ignition/gazebo/components/World.hh"
+#include "gz/sim/Conversions.hh"
+#include "gz/sim/Events.hh"
+#include "gz/sim/SdfEntityCreator.hh"
+#include "gz/sim/components/Geometry.hh"
+#include "gz/sim/components/LogPlaybackStatistics.hh"
+#include "gz/sim/components/Material.hh"
+#include "gz/sim/components/ParticleEmitter.hh"
+#include "gz/sim/components/Pose.hh"
+#include "gz/sim/components/World.hh"
 
-using namespace ignition;
-using namespace gazebo;
+using namespace gz;
+using namespace gz::sim;
 using namespace systems;
 
 /// \brief Private LogPlayback data class.
@@ -74,14 +73,6 @@ class ignition::gazebo::systems::LogPlaybackPrivate
   /// \return String of prepended path.
   public: std::string PrependLogPath(const std::string &_uri);
 
-  /// \brief Keeps track of which entity poses have updated
-  /// according to the given message.
-  /// \param[in] _msg Message containing pose updates.
-  /// \param[in] _clear Whether the most recently cached pose updates
-  /// should be deleted or not. Useful for when Parse is called multiple
-  /// times in the same Update cycle.
-  public: void Parse(const msgs::Pose_V &_msg, bool &_clear);
-
   /// \brief Updates the ECM according to the given message.
   /// \param[in] _ecm Mutable ECM.
   /// \param[in] _msg Message containing state updates.
@@ -122,10 +113,6 @@ class ignition::gazebo::systems::LogPlaybackPrivate
   /// plugin versions that did not record resources. False for older log files.
   public: bool doReplaceResourceURIs{true};
 
-  /// \brief Saves which entity poses have changed according to the latest
-  /// LogPlaybackPrivate::Parse call.
-  public: std::unordered_map<Entity, msgs::Pose> recentEntityPoseUpdates;
-
   // \brief Saves which particle emitter emitting components have changed
   public: std::unordered_map<Entity, bool> prevParticleEmitterCmds;
 };
@@ -149,24 +136,6 @@ LogPlayback::~LogPlayback()
     LogPlaybackPrivate::started = false;
 }
 
-//////////////////////////////////////////////////
-void LogPlaybackPrivate::Parse(const msgs::Pose_V &_msg, bool &_clear)
-{
-  if (_clear)
-    this->recentEntityPoseUpdates.clear();
-
-  // save the new entity pose updates
-  for (auto i=0; i < _msg.pose_size(); ++i)
-  {
-    const auto &pose = _msg.pose(i);
-    this->recentEntityPoseUpdates.insert_or_assign(pose.id(), pose);
-  }
-
-  // make sure that any future detected pose updates from the same Update
-  // cycle don't overwrite already-cached pose updates from the same cycle
-  _clear = false;
-}
-
 //////////////////////////////////////////////////
 void LogPlaybackPrivate::Parse(EntityComponentManager &_ecm,
     const msgs::SerializedStateMap &_msg)
@@ -519,39 +488,12 @@ void LogPlayback::Update(const UpdateInfo &_info, EntityComponentManager &_ecm)
   this->dataPtr->batch = this->dataPtr->log->QueryMessages(
       transport::log::AllTopics({startTime, endTime}));
 
-  msgs::Pose_V queuedPose;
-
-  // If new pose updates are received, make sure that only the cached poses
-  // from a previous Update cycle are cleared.
-  //
-  // Since Parse can be called multiple times in a single Update,
-  // it's important to make sure that new poses from a given Update aren't
-  // overwritten by poses received in a later Parse call from the same Update.
-  // Since Parse may not be called at all for a given Update (it depends on the
-  // timestamp being investigated from the log file), we will only clear cached
-  // poses from a previous Update if there are new poses to be saved in the
-  // current Update (we know that there are new poses to be saved if Parse
-  // is called).
-  bool clearCachedPoseUpdates = true;
-
   auto iter = this->dataPtr->batch.begin();
   while (iter != this->dataPtr->batch.end())
   {
     auto msgType = iter->Type();
 
-    // Only set the last pose of a sequence of poses.
-    if (msgType != "ignition.msgs.Pose_V" && queuedPose.pose_size() > 0)
-    {
-      this->dataPtr->Parse(queuedPose, clearCachedPoseUpdates);
-      queuedPose.Clear();
-    }
-
-    if (msgType == "ignition.msgs.Pose_V")
-    {
-      // Queue poses to be set later
-      queuedPose.ParseFromString(iter->Data());
-    }
-    else if (msgType == "ignition.msgs.SerializedState")
+    if (msgType == "ignition.msgs.SerializedState")
     {
       msgs::SerializedState msg;
       msg.ParseFromString(iter->Data());
@@ -617,29 +559,6 @@ void LogPlayback::Update(const UpdateInfo &_info, EntityComponentManager &_ecm)
     ++iter;
   }
 
-  if (queuedPose.pose_size() > 0)
-  {
-    this->dataPtr->Parse(queuedPose, clearCachedPoseUpdates);
-  }
-
-  // flag changed entity poses as periodically changed based on
-  // the latest LogPlaybackPrivate::Parse results
-  _ecm.Each<components::Pose>(
-      [&](const Entity &_entity, components::Pose *_poseComp) -> bool
-  {
-    if (this->dataPtr->recentEntityPoseUpdates.find(_entity) ==
-        this->dataPtr->recentEntityPoseUpdates.end())
-      return true;
-
-    msgs::Pose pose = this->dataPtr->recentEntityPoseUpdates.at(_entity);
-    *_poseComp = components::Pose(msgs::Convert(pose));
-
-    _ecm.SetChanged(_entity, components::Pose::typeId,
-        ComponentState::PeriodicChange);
-
-    return true;
-  });
-
     // particle emitters
   _ecm.Each<components::ParticleEmitterCmd>(
       [&](const Entity &_entity,
@@ -683,10 +602,14 @@ void LogPlayback::Update(const UpdateInfo &_info, EntityComponentManager &_ecm)
   }
 }
 
-IGNITION_ADD_PLUGIN(ignition::gazebo::systems::LogPlayback,
-                    ignition::gazebo::System,
+IGNITION_ADD_PLUGIN(LogPlayback,
+                    System,
                     LogPlayback::ISystemConfigure,
                     LogPlayback::ISystemUpdate)
 
-IGNITION_ADD_PLUGIN_ALIAS(ignition::gazebo::systems::LogPlayback,
+IGNITION_ADD_PLUGIN_ALIAS(LogPlayback,
+                          "gz::sim::systems::LogPlayback")
+
+// TODO(CH3): Deprecated, remove on version 8
+IGNITION_ADD_PLUGIN_ALIAS(LogPlayback,
                           "ignition::gazebo::systems::LogPlayback")
