@@ -17,7 +17,7 @@
 
 #include "PosePublisher.hh"
 
-#include <ignition/msgs/pose.pb.h>
+#include <gz/msgs/pose.pb.h>
 
 #include <stack>
 #include <string>
@@ -28,30 +28,30 @@
 
 #include <sdf/Joint.hh>
 
-#include <ignition/common/Profiler.hh>
-#include <ignition/math/Pose3.hh>
-#include <ignition/plugin/Register.hh>
-#include <ignition/transport/Node.hh>
+#include <gz/common/Profiler.hh>
+#include <gz/math/Pose3.hh>
+#include <gz/plugin/Register.hh>
+#include <gz/transport/Node.hh>
 
-#include "ignition/gazebo/Util.hh"
-#include "ignition/gazebo/components/CanonicalLink.hh"
-#include "ignition/gazebo/components/ChildLinkName.hh"
-#include "ignition/gazebo/components/Collision.hh"
-#include "ignition/gazebo/components/Joint.hh"
-#include "ignition/gazebo/components/JointType.hh"
-#include "ignition/gazebo/components/Link.hh"
-#include "ignition/gazebo/components/Model.hh"
-#include "ignition/gazebo/components/Name.hh"
-#include "ignition/gazebo/components/ParentEntity.hh"
-#include "ignition/gazebo/components/ParentLinkName.hh"
-#include "ignition/gazebo/components/Pose.hh"
-#include "ignition/gazebo/components/Sensor.hh"
-#include "ignition/gazebo/components/Visual.hh"
-#include "ignition/gazebo/Conversions.hh"
-#include "ignition/gazebo/Model.hh"
+#include "gz/sim/Util.hh"
+#include "gz/sim/components/CanonicalLink.hh"
+#include "gz/sim/components/ChildLinkName.hh"
+#include "gz/sim/components/Collision.hh"
+#include "gz/sim/components/Joint.hh"
+#include "gz/sim/components/JointType.hh"
+#include "gz/sim/components/Link.hh"
+#include "gz/sim/components/Model.hh"
+#include "gz/sim/components/Name.hh"
+#include "gz/sim/components/ParentEntity.hh"
+#include "gz/sim/components/ParentLinkName.hh"
+#include "gz/sim/components/Pose.hh"
+#include "gz/sim/components/Sensor.hh"
+#include "gz/sim/components/Visual.hh"
+#include "gz/sim/Conversions.hh"
+#include "gz/sim/Model.hh"
 
-using namespace ignition;
-using namespace gazebo;
+using namespace gz;
+using namespace gz::sim;
 using namespace systems;
 
 /// \brief Private data class for PosePublisher
@@ -156,12 +156,12 @@ class ignition::gazebo::systems::PosePublisherPrivate
   /// \brief A variable that gets populated with poses. This also here as a
   /// member variable to avoid repeated memory allocations and improve
   /// performance.
-  public: ignition::msgs::Pose poseMsg;
+  public: msgs::Pose poseMsg;
 
   /// \brief A variable that gets populated with poses. This also here as a
   /// member variable to avoid repeated memory allocations and improve
   /// performance.
-  public: ignition::msgs::Pose_V poseVMsg;
+  public: msgs::Pose_V poseVMsg;
 
   /// \brief True to publish a vector of poses. False to publish individual pose
   /// msgs.
@@ -263,23 +263,23 @@ void PosePublisher::Configure(const Entity &_entity,
   if (this->dataPtr->usePoseV)
   {
     this->dataPtr->posePub =
-      this->dataPtr->node.Advertise<ignition::msgs::Pose_V>(poseTopic);
+      this->dataPtr->node.Advertise<msgs::Pose_V>(poseTopic);
 
     if (this->dataPtr->staticPosePublisher)
     {
       this->dataPtr->poseStaticPub =
-          this->dataPtr->node.Advertise<ignition::msgs::Pose_V>(
+          this->dataPtr->node.Advertise<msgs::Pose_V>(
           staticPoseTopic);
     }
   }
   else
   {
     this->dataPtr->posePub =
-      this->dataPtr->node.Advertise<ignition::msgs::Pose>(poseTopic);
+      this->dataPtr->node.Advertise<msgs::Pose>(poseTopic);
     if (this->dataPtr->staticPosePublisher)
     {
       this->dataPtr->poseStaticPub =
-          this->dataPtr->node.Advertise<ignition::msgs::Pose>(
+          this->dataPtr->node.Advertise<msgs::Pose>(
           staticPoseTopic);
     }
   }
@@ -530,7 +530,7 @@ void PosePublisherPrivate::PublishPoses(
   IGN_PROFILE("PosePublisher::PublishPoses");
 
   // publish poses
-  ignition::msgs::Pose *msg = nullptr;
+  msgs::Pose *msg = nullptr;
   if (this->usePoseV)
     this->poseVMsg.Clear();
 
@@ -587,5 +587,9 @@ IGNITION_ADD_PLUGIN(PosePublisher,
                     PosePublisher::ISystemConfigure,
                     PosePublisher::ISystemPostUpdate)
 
+IGNITION_ADD_PLUGIN_ALIAS(PosePublisher,
+                          "gz::sim::systems::PosePublisher")
+
+// TODO(CH3): Deprecated, remove on version 8
 IGNITION_ADD_PLUGIN_ALIAS(PosePublisher,
                           "ignition::gazebo::systems::PosePublisher")
