@@ -16,7 +16,7 @@
 */
 
 #include <gtest/gtest.h>
-#include <ignition/gazebo/System.hh>
+#include <gz/sim/System.hh>
 
 /////////////////////////////////////////////////
 // Make sure the ignition namespace still works
