@@ -20,22 +20,23 @@
 #include <algorithm>
 #include <vector>
 
-#include <ignition/common/Console.hh>
-#include <ignition/common/Util.hh>
+#include <gz/common/Console.hh>
+#include <gz/common/Util.hh>
+#include <gz/utils/ExtraTestMacros.hh>
 #include <sdf/World.hh>
 
-#include "ignition/gazebo/components/Factory.hh"
-#include "ignition/gazebo/Server.hh"
-#include "ignition/gazebo/SystemLoader.hh"
-#include "ignition/gazebo/test_config.hh"  // NOLINT(build/include)
+#include "gz/sim/components/Factory.hh"
+#include "gz/sim/Server.hh"
+#include "gz/sim/SystemLoader.hh"
+#include "gz/sim/test_config.hh"  // NOLINT(build/include)
 
 #include "../helpers/Relay.hh"
 #include "../helpers/EnvTestFixture.hh"
 
-using namespace ignition;
+using namespace gz;
 using namespace std::chrono_literals;
 
-using IntComponent = gazebo::components::Component<int, class IntComponentTag>;
+using IntComponent = gz::sim::components::Component<int, class IntComponentTag>;
 IGN_GAZEBO_REGISTER_COMPONENT("ign_gazebo_components.IntComponent",
     IntComponent)
 
@@ -44,11 +45,13 @@ class EachNewRemovedFixture : public InternalFixture<::testing::Test>
 };
 
 /////////////////////////////////////////////////
-TEST_F(EachNewRemovedFixture, EachNewEachRemovedInSystem)
+// See https://github.com/gazebosim/gz-sim/issues/1175
+TEST_F(EachNewRemovedFixture,
+       IGN_UTILS_TEST_DISABLED_ON_WIN32(EachNewEachRemovedInSystem))
 {
-  ignition::gazebo::ServerConfig serverConfig;
+  gz::sim::ServerConfig serverConfig;
 
-  gazebo::Server server;
+  gz::sim::Server server;
 
   server.SetUpdatePeriod(1ns);
 
@@ -60,12 +63,12 @@ TEST_F(EachNewRemovedFixture, EachNewEachRemovedInSystem)
   // Entities to be created in a system. These have to be out here so the
   // entityCreator can set the ids when it creates the entities and the
   // entityRemover system can access them easily
-  gazebo::Entity e1 = gazebo::kNullEntity;
-  gazebo::Entity e2 = gazebo::kNullEntity;
+  gz::sim::Entity e1 = gz::sim::kNullEntity;
+  gz::sim::Entity e2 = gz::sim::kNullEntity;
 
-  gazebo::test::Relay entityCreator;
+  gz::sim::test::Relay entityCreator;
   entityCreator.OnPreUpdate(
-    [&](const gazebo::UpdateInfo &, gazebo::EntityComponentManager &_ecm)
+    [&](const gz::sim::UpdateInfo &, gz::sim::EntityComponentManager &_ecm)
     {
       if (shouldCreateEntities)
       {
@@ -78,9 +81,9 @@ TEST_F(EachNewRemovedFixture, EachNewEachRemovedInSystem)
       }
   });
 
-  gazebo::test::Relay entityRemover;
+  gz::sim::test::Relay entityRemover;
   entityRemover.OnPreUpdate(
-    [&](const gazebo::UpdateInfo &, gazebo::EntityComponentManager &_ecm)
+    [&](const gz::sim::UpdateInfo &, gz::sim::EntityComponentManager &_ecm)
     {
       if (shouldRemoveEntities)
       {
@@ -104,16 +107,16 @@ TEST_F(EachNewRemovedFixture, EachNewEachRemovedInSystem)
   {
     // Lambda to return. This a simple counter that uses the appropriate count
     // variable where count = (pre, update, post)count
-    auto counterImpl = [&](const gazebo::UpdateInfo &,
-                           const gazebo::EntityComponentManager &_ecm)
+    auto counterImpl = [&](const gz::sim::UpdateInfo &,
+                           const gz::sim::EntityComponentManager &_ecm)
     {
-      _ecm.EachNew<IntComponent>([&](const gazebo::Entity &,
+      _ecm.EachNew<IntComponent>([&](const gz::sim::Entity &,
                                      const IntComponent *) -> bool
       {
         ++_count.newEntities;
         return true;
       });
-      _ecm.EachRemoved<IntComponent>([&](const gazebo::Entity &,
+      _ecm.EachRemoved<IntComponent>([&](const gz::sim::Entity &,
                                          const IntComponent *) -> bool
       {
         ++_count.removedEntities;
@@ -123,7 +126,7 @@ TEST_F(EachNewRemovedFixture, EachNewEachRemovedInSystem)
     return counterImpl;
   };
 
-  gazebo::test::Relay entityCounter;
+  gz::sim::test::Relay entityCounter;
   entityCounter.OnPreUpdate(counterFunc(preCount));
   entityCounter.OnUpdate(counterFunc(updateCount));
   entityCounter.OnPostUpdate(counterFunc(postCount));
