@@ -17,21 +17,22 @@
 
 #include <gtest/gtest.h>
 
-#include <ignition/msgs/double.pb.h>
+#include <gz/msgs/double.pb.h>
 #include <mutex>
 
-#include <ignition/common/Console.hh>
-#include <ignition/common/Util.hh>
-#include <ignition/math/Pose3.hh>
-#include <ignition/transport/Node.hh>
+#include <gz/common/Console.hh>
+#include <gz/common/Util.hh>
+#include <gz/math/Pose3.hh>
+#include <gz/transport/Node.hh>
+#include <gz/utils/ExtraTestMacros.hh>
 
-#include "ignition/gazebo/Server.hh"
-#include "ignition/gazebo/SystemLoader.hh"
-#include "ignition/gazebo/test_config.hh"
+#include "gz/sim/Server.hh"
+#include "gz/sim/SystemLoader.hh"
+#include "gz/sim/test_config.hh"
 #include "../helpers/EnvTestFixture.hh"
 
-using namespace ignition;
-using namespace gazebo;
+using namespace gz;
+using namespace gz::sim;
 
 /// \brief Test Kinetic Energy Monitor system
 class KineticEnergyMonitorTest : public InternalFixture<::testing::Test>
@@ -51,7 +52,8 @@ void cb(const msgs::Double &_msg)
 
 /////////////////////////////////////////////////
 // The test checks the world pose and sensor readings of a falling altimeter
-TEST_F(KineticEnergyMonitorTest, ModelFalling)
+// See https://github.com/gazebosim/gz-sim/issues/1175
+TEST_F(KineticEnergyMonitorTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(ModelFalling))
 {
   // Start server
   ServerConfig serverConfig;
