@@ -17,32 +17,31 @@
 
 #include <gtest/gtest.h>
 
-#include <ignition/common/Console.hh>
-#include <ignition/common/Util.hh>
-#include <ignition/math/Pose3.hh>
+#include <gz/common/Console.hh>
+#include <gz/common/Util.hh>
+#include <gz/math/Pose3.hh>
 
-#include <ignition/gazebo/EntityComponentManager.hh>
-#include <ignition/gazebo/Model.hh>
-#include <ignition/gazebo/components/Joint.hh>
-#include <ignition/gazebo/components/Link.hh>
-#include <ignition/gazebo/components/Model.hh>
-#include <ignition/gazebo/components/Name.hh>
-#include <ignition/gazebo/components/ParentEntity.hh>
-#include <ignition/gazebo/components/PoseCmd.hh>
-#include <ignition/gazebo/components/SelfCollide.hh>
-#include <ignition/gazebo/components/SourceFilePath.hh>
-#include <ignition/gazebo/components/Static.hh>
-#include <ignition/gazebo/components/WindMode.hh>
+#include <gz/sim/EntityComponentManager.hh>
+#include <gz/sim/Model.hh>
+#include <gz/sim/components/CanonicalLink.hh>
+#include <gz/sim/components/Joint.hh>
+#include <gz/sim/components/Link.hh>
+#include <gz/sim/components/Model.hh>
+#include <gz/sim/components/Name.hh>
+#include <gz/sim/components/ParentEntity.hh>
+#include <gz/sim/components/PoseCmd.hh>
+#include <gz/sim/components/SelfCollide.hh>
+#include <gz/sim/components/SourceFilePath.hh>
+#include <gz/sim/components/Static.hh>
+#include <gz/sim/components/WindMode.hh>
 
-using namespace ignition;
-using namespace gazebo;
+#include "../helpers/EnvTestFixture.hh"
 
-class ModelIntegrationTest : public ::testing::Test
+using namespace gz;
+using namespace gz::sim;
+
+class ModelIntegrationTest : public InternalFixture<::testing::Test>
 {
-  public: void SetUp() override
-  {
-    ignition::common::Console::SetVerbosity(4);
-  }
 };
 
 //////////////////////////////////////////////////
@@ -234,3 +233,32 @@ TEST_F(ModelIntegrationTest, SetWorldPoseCmd)
   EXPECT_TRUE(ecm.HasOneTimeComponentChanges());
 }
 
+//////////////////////////////////////////////////
+TEST_F(ModelIntegrationTest, CanonicalLink)
+{
+  EntityComponentManager ecm;
+
+  // Model
+  auto eModel = ecm.CreateEntity();
+  Model model(eModel);
+  EXPECT_EQ(eModel, model.Entity());
+  EXPECT_EQ(0u, model.LinkCount(ecm));
+
+  // Links
+  auto canonicalLink = ecm.CreateEntity();
+  ecm.CreateComponent(canonicalLink, components::Link());
+  ecm.CreateComponent(canonicalLink, components::CanonicalLink());
+  ecm.CreateComponent(canonicalLink,
+      components::ParentEntity(eModel));
+  ecm.CreateComponent(canonicalLink, components::Name("canonical"));
+
+  auto anotherLink = ecm.CreateEntity();
+  ecm.CreateComponent(anotherLink, components::Link());
+  ecm.CreateComponent(anotherLink, components::ParentEntity(eModel));
+  ecm.CreateComponent(anotherLink, components::Name("another"));
+
+  // Check model
+  EXPECT_EQ(canonicalLink, model.CanonicalLink(ecm));
+  EXPECT_EQ(2u, model.LinkCount(ecm));
+}
+
