@@ -20,23 +20,24 @@
 #include <algorithm>
 #include <vector>
 
-#include <ignition/common/Console.hh>
-#include <ignition/common/Util.hh>
+#include <gz/common/Console.hh>
+#include <gz/common/Util.hh>
+#include <gz/utilities/ExtraTestMacros.hh>
 #include <sdf/World.hh>
 
-#include "ignition/gazebo/components/Factory.hh"
-#include "ignition/gazebo/components/Joint.hh"
-#include "ignition/gazebo/components/Link.hh"
-#include "ignition/gazebo/components/Model.hh"
-#include "ignition/gazebo/components/Name.hh"
-#include "ignition/gazebo/components/ParentEntity.hh"
-#include "ignition/gazebo/components/ParentLinkName.hh"
-#include "ignition/gazebo/components/Pose.hh"
-#include "ignition/gazebo/components/Recreate.hh"
-#include "ignition/gazebo/components/World.hh"
-#include "ignition/gazebo/Server.hh"
-#include "ignition/gazebo/SystemLoader.hh"
-#include "ignition/gazebo/test_config.hh"  // NOLINT(build/include)
+#include "gz/sim/components/Factory.hh"
+#include "gz/sim/components/Joint.hh"
+#include "gz/sim/components/Link.hh"
+#include "gz/sim/components/Model.hh"
+#include "gz/sim/components/Name.hh"
+#include "gz/sim/components/ParentEntity.hh"
+#include "gz/sim/components/ParentLinkName.hh"
+#include "gz/sim/components/Pose.hh"
+#include "gz/sim/components/Recreate.hh"
+#include "gz/sim/components/World.hh"
+#include "gz/sim/Server.hh"
+#include "gz/sim/SystemLoader.hh"
+#include "gz/sim/test_config.hh"  // NOLINT(build/include)
 
 #include "../helpers/Relay.hh"
 #include "../helpers/EnvTestFixture.hh"
@@ -52,12 +53,13 @@ class RecreateEntitiesFixture : public InternalFixture<::testing::Test>
 };
 
 /////////////////////////////////////////////////
-TEST_F(RecreateEntitiesFixture, RecreateEntities)
+TEST_F(RecreateEntitiesFixture,
+    IGN_UTILS_TEST_DISABLED_ON_WIN32(RecreateEntities))
 {
   // Start server
   ServerConfig serverConfig;
-  serverConfig.SetSdfFile(std::string(PROJECT_SOURCE_PATH) +
-      "/test/worlds/shapes.sdf");
+  serverConfig.SetSdfFile(common::joinPaths(std::string(PROJECT_SOURCE_PATH),
+      "test", "worlds", "shapes.sdf"));
 
   Server server(serverConfig);
   EXPECT_FALSE(server.Running());
@@ -133,8 +135,8 @@ TEST_F(RecreateEntitiesFixture, RecreateEntities)
 
     // Check entities
     // 1 x world + 1 x (default) level + 1 x wind + 5 x model + 5 x link + 5 x
-    // collision + 5 x visual + 1 x light
-    EXPECT_EQ(24u, ecm->EntityCount());
+    // collision + 5 x visual + 1 x light (light + visual)
+    EXPECT_EQ(25u, ecm->EntityCount());
 
     Entity worldEntity =
         ecm->EntityByComponents(components::World());
@@ -321,12 +323,13 @@ TEST_F(RecreateEntitiesFixture, RecreateEntities)
 }
 
 /////////////////////////////////////////////////
-TEST_F(RecreateEntitiesFixture, RecreateEntities_Joints)
+TEST_F(RecreateEntitiesFixture,
+    IGN_UTILS_TEST_DISABLED_ON_WIN32(RecreateEntities_Joints))
 {
   // Start server
   ServerConfig serverConfig;
-  serverConfig.SetSdfFile(std::string(PROJECT_SOURCE_PATH) +
-      "/test/worlds/double_pendulum.sdf");
+  serverConfig.SetSdfFile(common::joinPaths(std::string(PROJECT_SOURCE_PATH),
+      "test", "worlds", "double_pendulum.sdf"));
 
   Server server(serverConfig);
   EXPECT_FALSE(server.Running());
@@ -376,8 +379,8 @@ TEST_F(RecreateEntitiesFixture, RecreateEntities_Joints)
   {
     // Check entities
     // 1 x world + 1 x (default) level + 1 x wind + 5 x model + 5 x link + 5 x
-    // collision + 5 x visual + 1 x light
-    EXPECT_EQ(48u, ecm->EntityCount());
+    // collision + 5 x visual + 1 x light (light + visual)
+    EXPECT_EQ(49u, ecm->EntityCount());
 
     Entity worldEntity =
         ecm->EntityByComponents(components::World());
@@ -479,12 +482,13 @@ TEST_F(RecreateEntitiesFixture, RecreateEntities_Joints)
 }
 
 /////////////////////////////////////////////////
-TEST_F(RecreateEntitiesFixture, RecreateEntities_WorldJoint)
+TEST_F(RecreateEntitiesFixture,
+    IGN_UTILS_TEST_DISABLED_ON_WIN32(RecreateEntities_WorldJoint))
 {
   // Start server
   ServerConfig serverConfig;
-  serverConfig.SetSdfFile(std::string(PROJECT_SOURCE_PATH) +
-      "/test/worlds/fixed_world_joint.sdf");
+  serverConfig.SetSdfFile(common::joinPaths(std::string(PROJECT_SOURCE_PATH),
+      "test", "worlds", "fixed_world_joint.sdf"));
 
   Server server(serverConfig);
   EXPECT_FALSE(server.Running());
