@@ -15,8 +15,10 @@
  *
 */
 #include "Null.hh"
+#include <gz/sim/Entity.hh>
 #include <gz/plugin/Register.hh>
 
+using namespace ignition::gazebo;
 using namespace ignition::gazebo::systems;
 
 //////////////////////////////////////////////////
