@@ -16,7 +16,7 @@
 */
 #include "TestVisualSystem.hh"
 
-#include <ignition/plugin/Register.hh>
+#include <gz/plugin/Register.hh>
 
 IGNITION_ADD_PLUGIN(ignition::gazebo::TestVisualSystem,
     ignition::gazebo::System,
